@@ -61,6 +61,14 @@ impl super::Kubectl {
         }
     }
 
+    pub fn crds(&self) -> api::Api<apiextensionsv1::CustomResourceDefinition> {
+        self.api::<apiextensionsv1::CustomResourceDefinition>()
+    }
+
+    pub fn namespaces(&self) -> api::Api<corev1::Namespace> {
+        self.api::<corev1::Namespace>()
+    }
+
     pub fn secrets<'a>(&self, namespace: impl Into<Option<&'a str>>) -> api::Api<corev1::Secret> {
         if let Some(namespace) = namespace.into() {
             self.namespaced_api::<corev1::Secret>(namespace)
@@ -69,10 +77,6 @@ impl super::Kubectl {
         }
     }
 
-    pub fn crds(&self) -> api::Api<apiextensionsv1::CustomResourceDefinition> {
-        self.api::<apiextensionsv1::CustomResourceDefinition>()
-    }
-
     pub async fn get_secret(&self, name: &str) -> kube::Result<corev1::Secret> {
         self.secrets(None).get(name).await
     }
