@@ -20,7 +20,9 @@
 
 pub use k8s_openapi::api::apps::v1 as appsv1;
 pub use k8s_openapi::api::core::v1 as corev1;
+pub use k8s_openapi::api::rbac::v1 as rbacv1;
 pub use k8s_openapi::apiextensions_apiserver::pkg::apis::apiextensions::v1 as apiextensionsv1;
+pub use k8s_openapi::apimachinery::pkg::apis::meta::v1 as metav1;
 
 pub use kubectl::Kubectl;
 
